# HeadlessAgents Python SDK 1.0.0

Welcome to the HeadlessAgents SDK documentation. This guide will help you get started with integrating and using the HeadlessAgents SDK in your project.

[![This SDK was generated by liblab](https://public-liblab-readme-assets.s3.us-east-1.amazonaws.com/built-by-liblab-icon.svg)](https://liblab.com/?utm_source=readme)

## Versions

- API version: `1.0.0`
- SDK version: `1.0.0`

## About the API

API for interacting with Headless Agents

## Table of Contents

- [Setup & Configuration](#setup--configuration)
  - [Supported Language Versions](#supported-language-versions)
  - [Installation](#installation)
- [Authentication](#authentication)
  - [API Key Authentication](#api-key-authentication)
- [Setting a Custom Timeout](#setting-a-custom-timeout)
- [Sample Usage](#sample-usage)
- [Async Usage](#async-usage)
- [Services](#services)
- [Models](#models)

## Setup & Configuration

### Supported Language Versions

This SDK is compatible with the following versions: `Python >= 3.7`

### Installation

To get started with the SDK, we recommend installing using `pip`:

```bash
pip install headlessagents
```

## Authentication

### API Key Authentication

The HeadlessAgents API uses API keys as a form of authentication. An API key is a unique identifier used to authenticate a user, developer, or a program that is calling the API.

#### Setting the API key

When you initialize the SDK, you can set the API key as follows:

```py
HeadlessAgents(
    api_key="YOUR_API_KEY",
    timeout=10000
)
```

If you need to set or update the API key after initializing the SDK, you can use:

```py
sdk.set_api_key("YOUR_API_KEY")
```

## Setting a Custom Timeout

You can set a custom timeout for the SDK's HTTP requests as follows:

```py
from headlessagents import HeadlessAgents

sdk = HeadlessAgents(timeout=10000)
```

# Sample Usage

Below is a comprehensive example demonstrating how to authenticate and call a simple endpoint:

```py
from headlessagents import HeadlessAgents

sdk = HeadlessAgents(
    api_key="YOUR_API_KEY",
    timeout=10000
)

result = sdk.system.health_check()

print(result)

```

# Async Usage

The SDK includes an Async Client for making asynchronous API requests. This is useful for applications that need non-blocking operations, like web servers or apps with a graphical user interface.

```py
import asyncio
from headlessagents import HeadlessAgentsAsync

sdk = HeadlessAgentsAsync(
    api_key="YOUR_API_KEY",
    timeout=10000
)


async def main():
  result = await sdk.system.health_check()
  print(result)

asyncio.run(main())
```

## Services

The SDK provides various services to interact with the API.

<details> 
<summary>Below is a list of all available services with links to their detailed documentation:</summary>

| Name                                                           |
| :------------------------------------------------------------- |
| [SystemService](documentation/services/SystemService.md)       |
| [AgentsService](documentation/services/AgentsService.md)       |
| [ExecutionService](documentation/services/ExecutionService.md) |
| [AnalysisService](documentation/services/AnalysisService.md)   |
| [SchemaService](documentation/services/SchemaService.md)       |
| [ThreadsService](documentation/services/ThreadsService.md)     |

</details>

## Models

The SDK includes several models that represent the data structures used in API requests and responses. These models help in organizing and managing the data efficiently.

<details> 
<summary>Below is a list of all available models with links to their detailed documentation:</summary>

| Name                                                                     | Description |
| :----------------------------------------------------------------------- | :---------- |
| [HealthCheckOkResponse](documentation/models/HealthCheckOkResponse.md)   |             |
| [AgentCreate](documentation/models/AgentCreate.md)                       |             |
| [Agent](documentation/models/Agent.md)                                   |             |
| [AgentUpdate](documentation/models/AgentUpdate.md)                       |             |
| [CallAgentRequest](documentation/models/CallAgentRequest.md)             |             |
| [CallAgentOkResponse](documentation/models/CallAgentOkResponse.md)       |             |
| [DigestRequest](documentation/models/DigestRequest.md)                   |             |
| [CreateDigestOkResponse](documentation/models/CreateDigestOkResponse.md) |             |
| [SchemaCreateRequest](documentation/models/SchemaCreateRequest.md)       |             |
| [CreateSchemaOkResponse](documentation/models/CreateSchemaOkResponse.md) |             |
| [Thread](documentation/models/Thread.md)                                 |             |
| [ThreadMessage](documentation/models/ThreadMessage.md)                   |             |

</details>

<!-- This file was generated by liblab | https://liblab.com/ -->
